==> qtjambi-remoteobjects-5.15.17-sources.jar: io/qt/remoteobjects/QRemoteObjectAbstractPersistedStore.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A class which provides the methods for setting PROP values of a replica to value they had the last time the replica was used</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html">QRemoteObjectAbstractPersistedStore</a></code></p>
 */
public abstract class QRemoteObjectAbstractPersistedStore extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectAbstractPersistedStore.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QRemoteObjectAbstractPersistedStore {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig){
            return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
        }
        @QtUninvokable
        private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
        
        
        @Override
        @QtUninvokable
        public void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values){
            saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
        }
        @QtUninvokable
        private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
        
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#QRemoteObjectAbstractPersistedStore">QRemoteObjectAbstractPersistedStore::<wbr>QRemoteObjectAbstractPersistedStore(QObject*)</a></code></p>
     */
    public QRemoteObjectAbstractPersistedStore(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectAbstractPersistedStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#restoreProperties">QRemoteObjectAbstractPersistedStore::<wbr>restoreProperties(QString,<wbr>QByteArray)</a></code></p>
     */
    @QtUninvokable
    public abstract java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig);
    
    @QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#saveProperties">QRemoteObjectAbstractPersistedStore::<wbr>saveProperties(QString,<wbr>QByteArray,<wbr>QVariantList)</a></code></p>
     */
    @QtUninvokable
    public abstract void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values);
    
    @QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectAbstractPersistedStore instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectAbstractPersistedStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectAbstractPersistedStore() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-remoteobjects-5.15.19-sources.jar: io/qt/remoteobjects/QRemoteObjectAbstractPersistedStore.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>A class which provides the methods for setting PROP values of a replica to value they had the last time the replica was used</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html">QRemoteObjectAbstractPersistedStore</a></code></p>
 */
public abstract class QRemoteObjectAbstractPersistedStore extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectAbstractPersistedStore.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QRemoteObjectAbstractPersistedStore {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig){
            return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
        }
        @QtUninvokable
        private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
        
        
        @Override
        @QtUninvokable
        public void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values){
            saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
        }
        @QtUninvokable
        private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
        
    }
    
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#QRemoteObjectAbstractPersistedStore">QRemoteObjectAbstractPersistedStore::<wbr/>QRemoteObjectAbstractPersistedStore(QObject*)</a></code></p>
     */
    public QRemoteObjectAbstractPersistedStore(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectAbstractPersistedStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#restoreProperties">QRemoteObjectAbstractPersistedStore::<wbr/>restoreProperties(QString,<wbr/>QByteArray)</a></code></p>
     */
    @QtUninvokable
    public abstract java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig);
    
    @QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#saveProperties">QRemoteObjectAbstractPersistedStore::<wbr/>saveProperties(QString,<wbr/>QByteArray,<wbr/>QVariantList)</a></code></p>
     */
    @QtUninvokable
    public abstract void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values);
    
    @QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectAbstractPersistedStore instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectAbstractPersistedStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectAbstractPersistedStore() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded function for {@link #restoreProperties(java.lang.String, io.qt.core.QByteArray)}.</p>
     */
    @QtUninvokable
    public final java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, byte @NonNull[] repSig) {
        return restoreProperties(repName, new io.qt.core.QByteArray(repSig));
    }
    
    /**
     * <p>Overloaded function for {@link #saveProperties(java.lang.String, io.qt.core.QByteArray, java.util.Collection)}.</p>
     */
    @QtUninvokable
    public final void saveProperties(java.lang.@NonNull String repName, byte @NonNull[] repSig, java.util.@NonNull Collection<? extends java.lang.Object> values) {
        saveProperties(repName, new io.qt.core.QByteArray(repSig), values);
    }
}
